summaryrefslogtreecommitdiff
path: root/src/du.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2021-07-28 12:22:11 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2021-07-28 12:30:12 -0700
commitd60b2922ffb30d15e81b0019025b8e62af070a6e (patch)
tree094ede3f79355a438e50ca5d455206de7d1e84f4 /src/du.c
parent1625916a1ba4148b4127b7742337bde1606d4b80 (diff)
downloadcoreutils-d60b2922ffb30d15e81b0019025b8e62af070a6e.tar.gz
doc: modernize usage of “disk” and “core”
In documentation and comments, don’t assume that secondary storage devices are disk devices. Similarly, don’t assume that main memory uses magnetic cores, which became obsolete in the 1970s. * src/du.c (usage): * src/ls.c (usage): * src/shred.c (usage): Reword to avoid “disk” in usage messages.
Diffstat (limited to 'src/du.c')
-rw-r--r--src/du.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/du.c b/src/du.c
index efd519706..343f2e990 100644
--- a/src/du.c
+++ b/src/du.c
@@ -1,4 +1,4 @@
/* du -- summarize disk usage
Copyright (C) 1988-2021 Free Software Foundation, Inc.
This program is free software: you can redistribute it and/or modify
@@ -130,7 +130,7 @@ struct dulevel
/* If true, display counts for all files, not just directories. */
static bool opt_all = false;
/* If true, rather than using the disk usage of each file,
use the apparent size (a la stat.st_size). */
static bool apparent_size = false;
@@ -287,7 +287,7 @@ Usage: %s [OPTION]... [FILE]...\n\
or: %s [OPTION]... --files0-from=F\n\
"), program_name, program_name);
fputs (_("\
-Summarize disk usage of the set of FILEs, recursively for directories.\n\
+Summarize device usage of the set of FILEs, recursively for directories.\n\
"), stdout);
emit_mandatory_arg_note ();
@@ -295,7 +295,7 @@ Summarize disk usage of the set of FILEs, recursively for directories.\n\
fputs (_("\
-0, --null end each output line with NUL, not newline\n\
-a, --all write counts for all files, not just directories\n\
- --apparent-size print apparent sizes, rather than disk usage; although\
+ --apparent-size print apparent sizes rather than device usage; although\
\n\
the apparent size is usually smaller, it may be\n\
larger due to holes in ('sparse') files, internal\n\
@@ -315,7 +315,7 @@ Summarize disk usage of the set of FILEs, recursively for directories.\n\
--summarize\n\
"), stdout);
fputs (_("\
- --files0-from=F summarize disk usage of the\n\
+ --files0-from=F summarize device usage of the\n\
NUL-terminated file names specified in file F;\n\
if F is -, then read names from standard input\n\
-H equivalent to --dereference-args (-D)\n\
@@ -1,4 +1,4 @@
-/* du -- summarize disk usage
+/* du -- summarize device usage
Copyright (C) 1988-2021 Free Software Foundation, Inc.
This program is free software: you can redistribute it and/or modify
@@ -130,7 +130,7 @@ struct dulevel
/* If true, display counts for all files, not just directories. */
static bool opt_all = false;
-/* If true, rather than using the disk usage of each file,
+/* If true, rather than using the device usage of each file,
use the apparent size (a la stat.st_size). */
static bool apparent_size = false;